@@ -7,6 +7,7 @@ import inspect
 import json
 import logging
 import os
+import secrets
 import shlex
 import sys
 import warnings
@@ -14,10 +15,11 @@ from functools import lru_cache
 from itertools import groupby
 from numbers import Real
 
+import flask_login
 import jinja2
 import natsort
 import signac
-from flask import Flask, flash, g, render_template, request, session, url_for
+from flask import Flask, flash, g, redirect, render_template, request, session, url_for
 from flask_assets import Bundle, Environment
 from flask_turbolinks import turbolinks
 from watchdog.events import FileSystemEventHandler
@@ -37,11 +39,22 @@ class _FileSystemEventHandler(FileSystemEventHandler):
 
     def on_modified(self, event):
         if os.path.realpath(event.src_path) == os.path.realpath(
-            self.dashboard.project.workspace()
+            self.dashboard.project.workspace
         ):
             self.dashboard.update_cache()
 
 
+class User(flask_login.UserMixin):
+    """User class for flask_login.
+
+    The default implementation of `UserMixin` assumes that all instantiated User
+    classes are active and logged in.
+    """
+
+    def __init__(self, id):
+        self.id = id
+
+
 class Dashboard:
     """A dashboard application to display a :py:class:`signac.Project`.
 
@@ -63,6 +76,9 @@ class Dashboard:
       (default: 25).
     - **CARDS_PER_ROW**: Cards to show per row in the desktop view. Must be a
       factor of 12 (default: 3).
+    - **ACCESS_TOKEN**: The access token required to login to the dashboard.
+      Set to :code:`None` to disable authentication (not recommended on multi-user
+      systems).
     - **SECRET_KEY**: This must be specified to run via WSGI with multiple
       workers, so that sessions remain intact. See the
       `Flask docs <http://flask.pocoo.org/docs/1.0/config/#SECRET_KEY>`_
@@ -91,11 +107,14 @@ class Dashboard:
 
         self.event_handler = _FileSystemEventHandler(self)
         self.observer = Observer()
-        self.observer.schedule(self.event_handler, self.project.workspace())
+        self.observer.schedule(self.event_handler, self.project.workspace)
 
         # Prepare this dashboard instance to run.
 
         # Set configuration defaults
+        self.config.setdefault("HOST", "localhost")
+        self.config.setdefault("DEBUG", False)
+        self.config.setdefault("PORT", 8888)
         self.config.setdefault("PAGINATION", True)
         self.config.setdefault("PER_PAGE", 25)
         self.config.setdefault("CARDS_PER_ROW", 3)
@@ -105,9 +124,32 @@ class Dashboard:
                 f"{self.config['CARDS_PER_ROW']}."
             )
 
+        self.config.setdefault("ACCESS_TOKEN", secrets.token_urlsafe())
+
         # Create and configure the Flask application
         self.app = self._create_app(self.config)
 
+        # Initialize the login manager
+        self.login_manager = flask_login.LoginManager()
+        self.login_manager.init_app(self.app)
+
+        @self.login_manager.user_loader
+        def user_loader(identifier):
+            if self.config["ACCESS_TOKEN"] is None:
+                return User("None")
+
+            if secrets.compare_digest(identifier, self.config["ACCESS_TOKEN"]):
+                return User(identifier)
+
+            return None
+
+        @self.login_manager.request_loader
+        def load_user_from_request(request):
+            if self.config["ACCESS_TOKEN"] is None:
+                return User("None")
+
+            return None
+
         # Add assets and routes
         self.assets = self._create_assets()
         self._register_routes()
@@ -221,13 +263,14 @@ class Dashboard:
         interface. Arguments to this function are passed directly to
         :py:meth:`flask.Flask.run`.
         """
-        host = self.config.get("HOST", "localhost")
-        port = self.config.get("PORT", 8888)
+        host = self.config["HOST"]
+        port = self.config["PORT"]
+        debug = self.config["DEBUG"]
         max_retries = 5
 
         for _ in range(max_retries):
             try:
-                self.app.run(host, port, *args, **kwargs)
+                self.app.run(host=host, port=port, debug=debug, *args, **kwargs)
                 break
             except OSError as e:
                 logger.warning(e)
@@ -326,11 +369,6 @@ class Dashboard:
             )
             raise RuntimeError("ALLOW_WHERE must be enabled for this query.")
 
-        querytype = "statepoint"
-        if query[:4] == "doc:":
-            query = query[4:]
-            querytype = "document"
-
         try:
             if query is None:
                 f = None
@@ -341,10 +379,7 @@ class Dashboard:
                     query = shlex.split(query)
                     f = signac.contrib.filterparse.parse_filter_arg(query)
                     flash(f"Search string interpreted as '{json.dumps(f)}'.")
-            if querytype == "document":
-                jobs = self.project.find_jobs(doc_filter=f)
-            else:
-                jobs = self.project.find_jobs(filter=f)
+            jobs = self.project.find_jobs(filter=f)
             return sorted(jobs, key=lambda job: self.job_sorter(job))
         except json.JSONDecodeError as error:
             flash(
@@ -521,8 +556,6 @@ class Dashboard:
             return {
                 "APP_NAME": "signac-dashboard",
                 "APP_VERSION": __version__,
-                "PROJECT_NAME": self.project.config["project"],
-                "PROJECT_DIR": self.project.config["project_dir"],
                 "CARDS_PER_ROW": self.config["CARDS_PER_ROW"],
                 "modules": self.modules,
                 "modules_by_context": self._modules_by_context,
@@ -548,10 +581,26 @@ class Dashboard:
         def page_not_found(error):
             return self._render_error(str(error))
 
+        @dashboard.login_manager.unauthorized_handler
+        def unauthorized_handler():
+            return self._render_error("Access token is required.")
+
+        @dashboard.app.route("/login")
+        def login():
+            provided_token = request.args.get("token")
+            if provided_token == self.config["ACCESS_TOKEN"]:
+                user = User(provided_token)
+                flask_login.login_user(user)
+                return redirect("/")
+
+            return self._render_error("Invalid token")
+
         @dashboard.app.route("/favicon.ico")
+        @flask_login.login_required
         def favicon():
             return url_for("static", filename="favicon.ico")
 
+        # These routes are protected within the LazyView utility class
         self.add_url("views.home", ["/"])
         self.add_url("views.settings", ["/settings"])
         self.add_url("views.search", ["/search"])
@@ -590,7 +639,7 @@ class Dashboard:
         """Call the dashboard as a WSGI application."""
         return self.app(environ, start_response)
 
-    def main(self):
+    def main(self, command_args=None):
         """Runs the command line interface.
 
         Call this function to use signac-dashboard from its command line
@@ -611,8 +660,15 @@ class Dashboard:
         .. code-block:: bash
 
             python dashboard.py run
+
+        :param command_args: List of CLI arguments to pass, e.g.
+            ``["--debug", "--port", "8889"]`` (default: None).
+        :type command_args: list
         """
 
+        if command_args is not None and len(command_args) == 0:
+            command_args = None
+
         def _run(args):
             kwargs = vars(args)
             if kwargs.get("host", None) is not None:
@@ -621,6 +677,14 @@ class Dashboard:
                 self.config["PORT"] = kwargs.pop("port")
             self.config["PROFILE"] = kwargs.pop("profile")
             self.config["DEBUG"] = kwargs.pop("debug")
+
+            if self.config["ACCESS_TOKEN"] is not None:
+                print(
+                    f"To access this server, connect to: "
+                    f"http://{self.config['HOST']}:{self.config['PORT']}/"
+                    f"login?token={self.config['ACCESS_TOKEN']}"
+                )
+
             self.run()
 
         parser = argparse.ArgumentParser(
@@ -664,7 +728,7 @@ class Dashboard:
             print("signac-dashboard", __version__)
             sys.exit(0)
 
-        args = parser.parse_args()
+        args = parser.parse_args(command_args)
 
         if args.debug:
             logger.setLevel(logging.DEBUG)
