@@ -4,6 +4,7 @@ from .file_list import FileList
 from .flow_status import FlowStatus
 from .image_viewer import ImageViewer
 from .notes import Notes
+from .schema import Schema
 from .statepoint_list import StatepointList
 from .text_display import TextDisplay
 from .video_viewer import VideoViewer
@@ -15,6 +16,7 @@ __all__ = [
     "FlowStatus",
     "ImageViewer",
     "Notes",
+    "Schema",
     "StatepointList",
     "TextDisplay",
     "VideoViewer",
